@@ -1,5 +1,5 @@
 import datetime
-from dataclasses import dataclass, field
+from dataclasses import dataclass
 from typing import Any
 
 
@@ -82,7 +82,10 @@ class Security:
     def __post_init__(self) -> None:
         self.company_id = Company(**self.company_id)
         self.instrument_type = Instrument(**self.instrument_type)
-        self.share_group_id = ShareGroup(**self.share_group_id)
+        try:
+            self.share_group_id = ShareGroup(**self.share_group_id)
+        except TypeError:
+            self.share_group_id = None
 
 
 @dataclass
@@ -103,7 +106,7 @@ class DailyTrade:
 
 
 @dataclass
-class SecurityResponse:
+class SecurityResponseDetailed:
     security_daily_trade_dto: DailyTrade
     security: Security
     stock_listed_shares: int
@@ -123,9 +126,40 @@ class SecurityResponse:
 
 
 @dataclass
-class BaseSecurity:
-    id: int
-    symbol: str
-    name: str
-    active_status: str
+class SecurityResponse:
+    security_id: int
     security_name: str
+    symbol: int
+    index_id: int
+    open_price: int
+    high_price: int
+    low_price: int
+    total_trade_quantity: int
+    last_traded_price: int
+    percentage_change: float
+    last_updated_date_time: datetime.datetime
+    last_traded_volume: Any
+    previous_close: int
+
+
+@dataclass
+class LiveSecurityTrade:
+    id: int
+    business_date: datetime.date
+    security_id: int
+    symbol: str
+    security_name: str
+    open_price: int
+    high_price: int
+    low_price: int
+    close_price: int
+    total_traded_quantity: int
+    total_traded_value: int
+    previous_day_close_price: int
+    fifty_two_week_high: int
+    fifty_two_week_low: int
+    last_updated_time: datetime.datetime
+    last_updated_price: int
+    total_trades: int
+    average_traded_price: float
+    market_capitalization: float
